import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/device_managment/schedule_device/schedule_widgets/schedual_view.dart';
import 'package:syncrow_web/pages/device_managment/schedule_device/schedule_widgets/schedule_control_button.dart';
import 'package:syncrow_web/pages/device_managment/shared/toggle_widget.dart';
import 'package:syncrow_web/pages/device_managment/three_g_glass_switch/bloc/three_gang_glass_switch_bloc.dart';
import 'package:syncrow_web/pages/device_managment/three_g_glass_switch/factories/three_gang_glass_switch_bloc_factory.dart';
import 'package:syncrow_web/utils/constants/assets.dart';
import 'package:syncrow_web/utils/helpers/responsice_layout_helper/responsive_layout_helper.dart';
import '../models/three_gang_glass_switch.dart';

class ThreeGangGlassSwitchControlView extends StatelessWidget
    with HelperResponsiveLayout {
  final String deviceId;

  const ThreeGangGlassSwitchControlView({required this.deviceId, super.key});

  @override
  Widget build(BuildContext context) {
    return BlocProvider(
      create: (context) =>
          ThreeGangGlassSwitchBlocFactory.create(deviceId: deviceId)
            ..add(ThreeGangGlassSwitchFetchDeviceEvent(deviceId)),
      child: BlocBuilder<ThreeGangGlassSwitchBloc, ThreeGangGlassSwitchState>(
        builder: (context, state) {
          if (state is ThreeGangGlassSwitchLoading) {
            return const Center(child: CircularProgressIndicator());
          } else if (state is ThreeGangGlassSwitchStatusLoaded) {
            return _buildStatusControls(context, state.status);
          } else if (state is ThreeGangGlassSwitchError) {
            return const Center(child: Text('Error fetching status'));
          } else {
            return const Center(child: CircularProgressIndicator());
          }
        },
      ),
    );
  }

  Widget _buildStatusControls(
      BuildContext context, ThreeGangGlassStatusModel status) {
    final isExtraLarge = isExtraLargeScreenSize(context);
    final isLarge = isLargeScreenSize(context);
    final isMedium = isMediumScreenSize(context);
    return GridView(
      padding: const EdgeInsets.symmetric(horizontal: 50),
      shrinkWrap: true,
      physics: const NeverScrollableScrollPhysics(),
      gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisCount: isLarge || isExtraLarge
            ? 3
            : isMedium
                ? 2
                : 1,
        mainAxisExtent: 140,
        crossAxisSpacing: 12,
        mainAxisSpacing: 12,
      ),
      children: [
        ToggleWidget(
          value: status.switch1,
          code: 'switch_1',
          deviceId: deviceId,
          label: "Wall Light",
          onChange: (value) {
            context.read<ThreeGangGlassSwitchBloc>().add(
                  ThreeGangGlassSwitchControl(
                    deviceId: deviceId,
                    code: 'switch_1',
                    value: value,
                  ),
                );
          },
        ),
        ToggleWidget(
          value: status.switch2,
          code: 'switch_2',
          deviceId: deviceId,
          label: "Ceiling Light",
          onChange: (value) {
            context.read<ThreeGangGlassSwitchBloc>().add(
                  ThreeGangGlassSwitchControl(
                    deviceId: deviceId,
                    code: 'switch_2',
                    value: value,
                  ),
                );
          },
        ),
        ToggleWidget(
          value: status.switch3,
          code: 'switch_3',
          deviceId: deviceId,
          label: "SpotLight",
          onChange: (value) {
            context.read<ThreeGangGlassSwitchBloc>().add(
                  ThreeGangGlassSwitchControl(
                    deviceId: deviceId,
                    code: 'switch_3',
                    value: value,
                  ),
                );
          },
        ),
        ScheduleControlButton(
          onTap: () {
            showDialog<void>(
                context: context,
                builder: (ctx) => BlocProvider.value(
                      value: BlocProvider.of<ThreeGangGlassSwitchBloc>(context),
                      child: BuildScheduleView(
                        category: 'switch_1',
                        deviceUuid: deviceId,
                        countdownCode: 'countdown_1',
                        deviceType: '3GT',
                      ),
                    ));
          },
          mainText: 'Wall Light',
          subtitle: 'Scheduling',
          iconPath: Assets.scheduling,
        ),
        ScheduleControlButton(
          onTap: () {
            showDialog<void>(
                context: context,
                builder: (ctx) => BlocProvider.value(
                      value: BlocProvider.of<ThreeGangGlassSwitchBloc>(context),
                      child: BuildScheduleView(
                        category: 'switch_2',
                        deviceUuid: deviceId,
                        countdownCode: 'countdown_2',
                        deviceType: '3GT',
                      ),
                    ));
          },
          mainText: 'Ceiling Light',
          subtitle: 'Scheduling',
          iconPath: Assets.scheduling,
        ),
        ScheduleControlButton(
          onTap: () {
            showDialog<void>(
                context: context,
                builder: (ctx) => BlocProvider.value(
                      value: BlocProvider.of<ThreeGangGlassSwitchBloc>(context),
                      child: BuildScheduleView(
                        category: 'switch_3',
                        deviceUuid: deviceId,
                        countdownCode: 'countdown_3',
                        deviceType: '3GT',
                      ),
                    ));
          },
          mainText: 'SpotLight',
          subtitle: 'Scheduling',
          iconPath: Assets.scheduling,
        ),
        ToggleWidget(
          value: false,
          code: '',
          deviceId: deviceId,
          label: 'Preferences',
          icon: Assets.preferences,
          onChange: (value) {},
          showToggle: false,
        ),
      ],
    );
  }
}
